from django.db import models
from django.utils.translation import ugettext_lazy as _


class ExerciseTree(models.Model):
    item_id = models.AutoField(primary_key=True)
    parent_id = models.IntegerField(help_text='This is the parent menu ID. 0 if it is on the top of the tree')
    name = models.CharField(max_length=100, help_text='The name should be in English here')
    image_url = models.ImageField(upload_to='images/', help_text='The menu image size is 1366x768')
    active = models.BooleanField(default=0, blank=True, null=True)

    class Meta:
        db_table = 'exercise_tree'
        verbose_name = _("Exercise Tree")
        verbose_name_plural = _("Exercise Tree Items")

    def __str__(self):
        return self.name


class ExerciseType(models.Model):
    class UnitTypes(models.TextChoices):
        REPEAT = 'repeat'
        SECOND = 'second'
        MINUTE = 'minute'
        METER = 'meter'
        CM = 'centimeter'
        PERCENT = 'percent'
        CALORIES = 'calories'
        KG = 'kilogram'

    exercise_type_id = models.AutoField(primary_key=True)
    tree = models.ForeignKey(ExerciseTree, on_delete=models.CASCADE)
    name = models.CharField(max_length=100, help_text='The name should be in English here')
    description = models.TextField(max_length=1000, blank=True, null=True, help_text='The description should be in '
                                                                                     'English here')
    unit = models.CharField(choices=UnitTypes.choices, default=UnitTypes.REPEAT, max_length=50, blank=True, null=True)
    unit_quantity = models.BooleanField(default=0, blank=True, null=True)
    unit_quantity_unit = models.CharField(choices=UnitTypes.choices, default=UnitTypes.KG, max_length=50, blank=True,
                                          null=True)
    active = models.BooleanField(default=0, blank=True, null=True)

    class Meta:
        db_table = 'exercise_type'
        verbose_name = _("Exercise")
        verbose_name_plural = _("Exercises")

    def __str__(self):
        return self.name


class ExerciseTypeImage(models.Model):
    class ImageTypes(models.TextChoices):
        IMAGE = 'image'
        VIDEO = 'video'
        MENU = 'menu'

    image_id = models.AutoField(primary_key=True)
    exercise_type = models.ForeignKey(ExerciseType, on_delete=models.CASCADE)
    name = models.CharField(max_length=50, blank=True, null=True)
    type = models.CharField(choices=ImageTypes.choices, default=ImageTypes.IMAGE, max_length=50, blank=True, null=True)
    url = models.ImageField(upload_to='images/', help_text='The menu image size is 1366x768')

    class Meta:
        db_table = 'exercise_type_image'
        verbose_name = _("Image")
        verbose_name_plural = _("Images")

    def __str__(self):
        return self.name


class LanguageTypes(models.TextChoices):
    EN = "en"
    HU = "hu"


class ExerciseTypeTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    exercise_type = models.ForeignKey(ExerciseType, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    name = models.CharField(max_length=100)
    description = models.TextField(max_length=1000, blank=True, null=True)

    class Meta:
        db_table = 'exercise_type_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")

    def __str__(self):
        return self.name


class ExerciseTreeTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    tree = models.ForeignKey(ExerciseTree, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    name = models.CharField(max_length=100)

    class Meta:
        db_table = 'exercise_tree_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")

    def __str__(self):
        return self.name
